--------------------------------------------------------------------------------
-- Version history...
--  0.0.1 - Basic modul handling
--------------------------------------------------------------------------------


-- Debug mode (true=on, nil=off)
local DEBUG_MODE = true;

-- Flags of the init routines
local AoADemoMod_Initialized = false;
local AoADemoMod_ADDON_LOADED = false;
local AoADemoMod_VARIABLES_LOADED = false;


local function AoA_ChatMessage(text)
	AoAMod_ChatMessage("DemoMod", text);
end

local function AoA_ChatError(text)
	AoAMod_ChatError("DemoMod", text);
end

local function AoA_ChatWarning(text)
	AoAMod_ChatWarning("DemoMod", text);
end

local function AoA_ChatDebug(text)
	if (DEBUG_MODE) then AoAMod_ChatDebug("DemoMod", text); end
end


--------------------------------------------------------------------------------
-- OnLoad
--------------------------------------------------------------------------------
function AoADemoMod_OnLoad()

	-- Register for the following events
	this:RegisterEvent("ADDON_LOADED");
	this:RegisterEvent("VARIABLES_LOADED");
	this:RegisterEvent("PLAYER_ENTERING_WORLD");
	this:RegisterEvent("PLAYER_LEAVING_WORLD");
	
end

function AoADemoMod_RegisterEvents()
end

function AoADemoMod_UnregisterEvents()
end


--------------------------------------------------------------------------------
-- Initializes everything relating to saved variables and data in other lua files
-- This should be called ONLY when we're sure that all other files have been loaded
--------------------------------------------------------------------------------
function AoADemoMod_Init()
	
	-- init module
	info = {
		frame = AoADemoModulFrame;
		init  = AoADemoMod_InitModule;
		text  = AOA_DEMOMODUL_TABTEXT;
		addon = "AoA_DemoModul";
		};
	AoA_RegisterModule(info);
	
	-- AddOn is initialized now
	AoADemoMod_Initialized = true;
	AoA_ChatMessage(string.format(AOA_LOADED, GetAddOnMetadata("AoA_DemoModul", "Version")));
	
end


--------------------------------------------------------------------------------
-- Initializes the module
-- called by the core addon
--------------------------------------------------------------------------------
function AoADemoMod_InitModule()
	
	-- setup the saved variables if needed
	AoADemoMod_InitSavedVars();
	
end


--------------------------------------------------------------------------------
-- Create all the necessary saved variables if they don't exist
-- The default settings for all saved variables are stored here
--------------------------------------------------------------------------------
function AoADemoMod_InitSavedVars()
end


--------------------------------------------------------------------------------
-- OnEvent
--------------------------------------------------------------------------------
function AoADemoMod_OnEvent()

	if ( event == "ADDON_LOADED" and arg1 == "AoA_DemoModul") then
		AoADemoMod_ADDON_LOADED = true;
	elseif ( event == "VARIABLES_LOADED" ) then
		AoADemoMod_VARIABLES_LOADED = true;
	elseif ( event == "PLAYER_ENTERING_WORLD" ) then
		AoADemoMod_RegisterEvents();
	elseif ( event == "PLAYER_LEAVING_WORLD" ) then
		AoADemoMod_UnregisterEvents();
	end
	
	-- Once these two events have fired we can assume that all other files have been loaded
	-- It's now safe to initialize AtlasEnhanced if it hasn't already been done
	if ( AoADemoMod_ADDON_LOADED and AoADemoMod_VARIABLES_LOADED and AoADemoMod_Initialized == false ) then
		AoADemoMod_Init();
	end
	
end
